@@ -12,24 +12,24 @@ convert_attributes <- function(dat) {
   attr(out, "types") <- NULL
   attr(out, "label.table") <- NULL
   for (i in 1:length(out)) {
-    if ("value.labels" %in% names(attributes(out[,i]))) {
-      attr(out[,i], "labels") <- attr(out[,i], "value.labels")
-      attr(out[,i], "value.labels") <- NULL
+    if ("value.labels" %in% names(attributes(out[[i]]))) {
+      attr(out[[i]], "labels") <- attr(out[[i]], "value.labels")
+      attr(out[[i]], "value.labels") <- NULL
     }
-    if (inherits(out[,i], "labelled")) {
-      out[,i] <- unclass(out[,i])
+    if (inherits(out[[i]], "labelled")) {
+      out[[i]] <- unclass(out[[i]])
     }
     if ("var.labels" %in% names(a)) {
-      attr(out[,i], "label") <- a$var.labels[i]
+      attr(out[[i]], "label") <- a$var.labels[i]
     }
     if ("formats" %in% names(a)) {
-      attr(out[,i], "format") <- a$formats[i]
+      attr(out[[i]], "format") <- a$formats[i]
     }
     if ("types" %in% names(a)) {
-      attr(out[,i], "type") <- a$types[i]
+      attr(out[[i]], "type") <- a$types[i]
     }
     if ("val.labels" %in% names(a) && (a$val.labels[i] != "")) {
-      attr(out[,i], "labels") <- a$label.table[[a$val.labels[i]]]
+      attr(out[[i]], "labels") <- a$label.table[[a$val.labels[i]]]
     }
   }
   out
