@@ -18,13 +18,24 @@ test_that("Export to CSV", {
 })
 
 test_that("Import from CSV (read.csv)", {
-    expect_error(is.data.frame(import("iris.csv")))
     expect_true(is.data.frame(import("iris.csv", format = "csv2")))
 })
 
 test_that("Import from CSV (fread)", {
-    expect_error(is.data.frame(import("iris.csv", fread = TRUE)))
     expect_true(is.data.frame(import("iris.csv", format = "csv2", fread = TRUE)))
 })
 
+test_that("Export to TSV with CSV extension", {
+    expect_true(export(iris, "iris.csv", format = "tsv") %in% dir())
+})
+
+test_that("Import from TSV with CSV extension", {
+    expect_true(ncol(import("iris.csv")) == 5L)
+    expect_true(ncol(import("iris.csv", format = "tsv")) == 5L)
+    expect_true(ncol(import("iris.csv", format = "tsv", sep = "\t")) == 5L)
+    expect_true(ncol(import("iris.csv", sep = ",")) == 1L)
+    expect_true(ncol(import("iris.csv", format = "csv")) == 5L)
+    expect_true(ncol(import("iris.csv", sep = "auto")) == 5L)
+})
+
 unlink("iris.csv")
